
Avem theme
---------------------------------

A simply responsive Bootstrap 3 theme for Django. Made for my own use, but if you want to use it or parts of it, do feel free.

License
---------------------------------

django_avem_theme is available under the revised BSD license, see LICENSE.txt. You can do anything as long as you include the license, don't use my name for promotion and are aware that there is no warranty.


